# Julia: Fast as Fortran, Beautiful as Python

**URL:** <https://fortran-lang.discourse.group/t/julia-fast-as-fortran-beautiful-as-python/1405>\
**Category:** Uncategorized\
**Created:** [June 20, 2021, 6:21pm UTC](https://fortran-lang.discourse.group/t/julia-fast-as-fortran-beautiful-as-python/1405 "2021-06-20T18:21:13Z")\
**Posts on this page:** 1\
**Showing post:** 143

<div class="post-metadata">

**Author:** ![FortranFan](https://avatars.discourse-cdn.com/v4/letter/f/96bed5/32.png) [@FortranFan](https://fortran-lang.discourse.group/u/FortranFan)\
**Post date:** [July 10, 2021, 1:21pm UTC](https://fortran-lang.discourse.group/t/julia-fast-as-fortran-beautiful-as-python/1405/143 "2021-07-10T13:21:32Z")

</div>

> [@shahmoradi](#):
>
> So, does Julia vectorize a compiled external library at the request of the user, or does it recompile the library every time to achieve the goal?

Please see this example where the key computation, the sine of a radian, was moved to an external library, `cordic_sine`: [Simple summation 8x slower than in Julia - #44 by FortranFan](https://fortran-lang.discourse.group/t/simple-summation-8x-slower-than-in-julia/1171/44).

Once that was done, note in all the subsequent scenarios, the ratio of compute times with Fortran vs Julia were around unity, meaning no real difference i.e., the specific advantages with an enthusiast-driven `macro` implementation toward **vectorization** and specific “fast” trig functions leading to the original 8x difference became inapplicable.

---

_[View the full topic](https://fortran-lang.discourse.group/t/julia-fast-as-fortran-beautiful-as-python/1405)._
